"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toNumber = exports.security = exports.currency = exports.isValidBankCard = exports.isInteger = exports.halfSpace = exports.digitsToWords = exports.switchKey = exports.decodeURL = exports.arabicNumber = exports.persianNumber = exports.englishNumber = exports.persianChar = void 0;
// Declare Number Arrays in different locales
var regExpArabicNumber = new RegExp(/[\u0660-\u0669]/, "g"), regExpPersianNumber = new RegExp(/[\u06f0-\u06f9]/, "g"), regExpEnglishNumber = new RegExp(/[\u0030-\u0039]/, "g");
/** Used for convert Arabic characters to Persian */
function persianChar(value) {
    if (!value) {
        return "";
    }
    var arabicChars = [
        "ي",
        "ك",
        "‍",
        "دِ",
        "بِ",
        "زِ",
        "ذِ",
        "ِشِ",
        "ِسِ",
        "ى",
    ], persianChars = ["ی", "ک", "", "د", "ب", "ز", "ذ", "ش", "س", "ی"];
    for (var i = 0, charsLen = arabicChars.length; i < charsLen; i++) {
        value = value.replace(new RegExp(arabicChars[i], "g"), persianChars[i]);
    }
    return value;
}
exports.persianChar = persianChar;
/** Used for convert any numbers to English */
function englishNumber(value) {
    if (!value) {
        return value;
    }
    return value
        .replace(regExpArabicNumber, function (c) {
        return (c.charCodeAt(0) - 0x0660);
    })
        .replace(regExpPersianNumber, function (c) {
        return (c.charCodeAt(0) - 0x06f0);
    });
}
exports.englishNumber = englishNumber;
/** Used for convert any numbers to Persian */
function persianNumber(value) {
    if (!value) {
        return "";
    }
    return value
        .replace(regExpArabicNumber, function (c) {
        return String.fromCharCode(parseInt((c.charCodeAt(0) - 0x0660), 10) + 0x06f0);
    })
        .replace(regExpEnglishNumber, function (c) {
        return String.fromCharCode(parseInt(c, 10) + 0x06f0);
    });
}
exports.persianNumber = persianNumber;
/** Used for convert any numbers to arabic */
function arabicNumber(value) {
    if (!value) {
        return "";
    }
    value = value.toString();
    return value
        .replace(regExpPersianNumber, function (c) {
        return String.fromCharCode(parseInt((c.charCodeAt(0) - 0x06f0), 10) + 0x0660);
    })
        .replace(regExpEnglishNumber, function (c) {
        return String.fromCharCode(parseInt(c, 10) + 0x0660);
    });
}
exports.arabicNumber = arabicNumber;
/**
 * Used for decode Persian Characters in URL
 * https://fa.wikipedia.org/wiki/مدیاویکی:Gadget-Extra-Editbuttons-Functions.js
 */
function decodeURL(value) {
    if (!value) {
        return "";
    }
    // Replace every %20 with _ to protect them from decodeURI
    var old = "";
    while (old !== value) {
        old = value;
        value = value.replace(/(http\S+?)%20/g, "$1\u200c\u200c\u200c_\u200c\u200c\u200c");
    }
    // Decode URIs
    // NOTE: This would convert all %20's to _'s which could break some links
    // but we will undo that later on
    value = value.replace(/(http\S+)/g, function (s, p) {
        return decodeURI(p);
    });
    // Revive all instances of %20 to make sure no links is broken
    return value.replace(/\u200c\u200c\u200c_\u200c\u200c\u200c/g, "%20");
}
exports.decodeURL = decodeURL;
/** Used for Change keyboard layout */
function switchKey(value) {
    if (!value) {
        return "";
    }
    var persianChars = [
        "ض",
        "ص",
        "ث",
        "ق",
        "ف",
        "غ",
        "ع",
        "ه",
        "خ",
        "ح",
        "ج",
        "چ",
        "ش",
        "س",
        "ی",
        "ب",
        "ل",
        "ا",
        "ت",
        "ن",
        "م",
        "ک",
        "گ",
        "ظ",
        "ط",
        "ز",
        "ر",
        "ذ",
        "د",
        "پ",
        "و",
        "؟",
    ], englishChar = [
        "q",
        "w",
        "e",
        "r",
        "t",
        "y",
        "u",
        "i",
        "o",
        "p",
        "[",
        "]",
        "a",
        "s",
        "d",
        "f",
        "g",
        "h",
        "j",
        "k",
        "l",
        ";",
        "'",
        "z",
        "x",
        "c",
        "v",
        "b",
        "n",
        "m",
        ",",
        "?",
    ];
    for (var i = 0, charsLen = persianChars.length; i < charsLen; i++) {
        value = value.replace(new RegExp(persianChars[i], "g"), englishChar[i]);
    }
    return value;
}
exports.switchKey = switchKey;
/** Used for get persian words representation of a number */
function digitsToWords(value) {
    if (!isFinite(value)) {
        return "";
    }
    if (typeof value !== "string") {
        value = value.toString();
    }
    var parts = [
        "",
        "هزار",
        "میلیون",
        "میلیارد",
        "تریلیون",
        "کوادریلیون",
        "کویینتیلیون",
        "سکستیلیون",
    ];
    var numbers = {
        0: [
            "",
            "صد",
            "دویست",
            "سیصد",
            "چهارصد",
            "پانصد",
            "ششصد",
            "هفتصد",
            "هشتصد",
            "نهصد",
        ],
        1: ["", "ده", "بیست", "سی", "چهل", "پنجاه", "شصت", "هفتاد", "هشتاد", "نود"],
        2: ["", "یک", "دو", "سه", "چهار", "پنج", "شش", "هفت", "هشت", "نه"],
        two: [
            "ده",
            "یازده",
            "دوازده",
            "سیزده",
            "چهارده",
            "پانزده",
            "شانزده",
            "هفده",
            "هجده",
            "نوزده",
        ],
        zero: "صفر",
    };
    var delimiter = " و ";
    var valueParts = value
        .split("")
        .reverse()
        .join("")
        .replace(/\d{3}(?=\d)/g, "$&,")
        .split("")
        .reverse()
        .join("")
        .split(",")
        .map(function (str) {
        return Array(4 - str.length).join("0") + str;
    });
    var result = (function () {
        var _results = [];
        var _loop_1 = function (iThree) {
            var three = valueParts[iThree];
            var resultThree = (function () {
                var _i;
                var _results1 = [];
                for (var i = (_i = 0), _len = three.length; _i < _len; i = ++_i) {
                    var digit = three[i];
                    if (i === 1 && digit === "1") {
                        _results1.push(numbers.two[three[2]]);
                    }
                    else if ((i !== 2 || three[1] !== "1") &&
                        numbers[i][digit] !== "") {
                        _results1.push(numbers[i][digit]);
                    }
                    else {
                        continue;
                    }
                }
                return _results1;
            })();
            var resultThreeString = resultThree.join(delimiter);
            var _result = resultThreeString
                ? resultThreeString +
                    " " +
                    parts[valueParts.length - parseInt(iThree, 10) - 1]
                : resultThreeString;
            _results.push(_result);
        };
        for (var iThree in valueParts) {
            _loop_1(iThree);
        }
        return _results;
    })();
    result = result.filter(function (x) {
        return x.trim() !== "";
    });
    var resultString = result.join(delimiter).trim();
    if (resultString === "") {
        return numbers.zero;
    }
    return resultString;
}
exports.digitsToWords = digitsToWords;
/** Used for Zero-width non-joiner correction */
function halfSpace(value) {
    if (!value) {
        return "";
    }
    // Replace Zero-width non-joiner between persian MI.
    var pattern = /((\s\u0645\u06CC)+( )+([\u0600-\u06EF]{1,}){1,})/g;
    value = value.replace(new RegExp(pattern), "$2\u200C$4");
    // Replace Zero-width non-joiner between persian De-Yii.
    pattern = /(([\u0600-\u06EF]{1,})+( )+(ای|ایی|اند|ایم|اید|ام){1})/g;
    value = value.replace(new RegExp(pattern), "$2\u200C$4");
    return value;
}
exports.halfSpace = halfSpace;
/** Convert numbers to english number and remove anything expect integer or decimal numbers */
function toNumber(value, _a) {
    var _b, _c, _d, _e;
    var _f = _a === void 0 ? {} : _a, _g = _f.negative, negative = _g === void 0 ? true : _g, _h = _f.decimal, decimal = _h === void 0 ? true : _h, max = _f.max, min = _f.min;
    var num = ((_b = englishNumber(value)
        .match(/(-?\.?\d?)+/g)) === null || _b === void 0 ? void 0 : _b.join("")) || "";
    // if (options?.negative && options?.decimal) {
    // }
    if (decimal && negative) {
        num = num.replace(/(^.+)(-)/g, "$1");
        num = num.replace(/^\./g, "0.");
        num = num.replace(/^-\./g, "-0.");
        num = ((_c = num.match(/^-?\d*\.?\d*$/g)) === null || _c === void 0 ? void 0 : _c.join("")) || "";
    }
    else {
        if (negative) {
            num = num.replace(/(^.+)(-)/g, "$1");
            num = ((_d = num.match(/^-?(\d?)+$/g)) === null || _d === void 0 ? void 0 : _d.join("")) || "";
        }
        else if (decimal) {
            num = num.replace(/^\./g, "0.");
            num = ((_e = num.match(/\d*\.?\d*$/g)) === null || _e === void 0 ? void 0 : _e.join("")) || "";
        }
        else {
            num = num.replace(/\D/g, "");
        }
    }
    if (typeof max === "number") {
        if (Number(num) > max) {
            num = String(max);
        }
    }
    if (typeof min === "number") {
        if (Number(num) < min) {
            num = String(min);
        }
    }
    return num;
}
exports.toNumber = toNumber;
/** Used for validation integer number */
function isInteger(value) {
    return Number.isInteger(Number(value));
}
exports.isInteger = isInteger;
/**
 * Used for validation back card number
 *
 * @param {string} value 16 digit
 */
function isValidBankCard(value) {
    // accept only digits, dashes or spaces
    if (!isInteger(value))
        return false;
    // The Luhn Algorithm. It's so pretty.
    var nCheck = 0, bEven = false;
    value = value.replace(/\D/g, "");
    for (var n = value.length - 1; n >= 0; n--) {
        var cDigit = value.charAt(n);
        var nDigit = parseInt(cDigit, 10);
        if (bEven) {
            if ((nDigit *= 2) > 9)
                nDigit -= 9;
        }
        nCheck += nDigit;
        bEven = !bEven;
    }
    return nCheck % 10 === 0;
}
exports.isValidBankCard = isValidBankCard;
/** Used for convert english number to currency mode */
function currency(value) {
    if (!value)
        return "";
    return value
        .replace(/[^\d.-]/g, "")
        .replace(/(\.\d{2})[\W\w]+/g, "$1")
        .split("")
        .reverse()
        .join("")
        .replace(/(\d{3})/g, "$1,")
        .split("")
        .reverse()
        .join("")
        .replace(/^([-]{0,1}),/, "$1")
        .replace(/(\.\d)$/, "$1" + "0")
        .replace(/\.$/, ".00");
}
exports.currency = currency;
/** Convert any char to star ("*") */
function security(value) {
    return "*".repeat(value.length);
}
exports.security = security;
//# sourceMappingURL=lib.js.map